==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/PdfaLevelType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p179225_="https://jakarta.ee/xml/ns/jaxb" xmlns:p413817_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Specifies the compliance level when creating or validating PDF/A documents (as specified in ISO 19005).&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PdfaLevelType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="PdfaLevelType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="1a"/>
 *     <enumeration value="1b"/>
 *     <enumeration value="2a"/>
 *     <enumeration value="2b"/>
 *     <enumeration value="2u"/>
 *     <enumeration value="3a"/>
 *     <enumeration value="3b"/>
 *     <enumeration value="3u"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "PdfaLevelType")
@XmlEnum
public enum PdfaLevelType {

    @XmlEnumValue("1a")
    LEVEL_1A("1a"),
    @XmlEnumValue("1b")
    LEVEL_1B("1b"),
    @XmlEnumValue("2a")
    LEVEL_2A("2a"),
    @XmlEnumValue("2b")
    LEVEL_2B("2b"),
    @XmlEnumValue("2u")
    LEVEL_2U("2u"),
    @XmlEnumValue("3a")
    LEVEL_3A("3a"),
    @XmlEnumValue("3b")
    LEVEL_3B("3b"),
    @XmlEnumValue("3u")
    LEVEL_3U("3u");
    private final String value;

    PdfaLevelType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static PdfaLevelType fromValue(String v) {
        for (PdfaLevelType c: PdfaLevelType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/PdfaLevelType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p567934_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p643558_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Specifies the compliance level when creating or validating PDF/A documents (as specified in ISO 19005).&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for PdfaLevelType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="PdfaLevelType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="1a"/>
 *     <enumeration value="1b"/>
 *     <enumeration value="2a"/>
 *     <enumeration value="2b"/>
 *     <enumeration value="2u"/>
 *     <enumeration value="3a"/>
 *     <enumeration value="3b"/>
 *     <enumeration value="3u"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "PdfaLevelType")
@XmlEnum
public enum PdfaLevelType {

    @XmlEnumValue("1a")
    LEVEL_1A("1a"),
    @XmlEnumValue("1b")
    LEVEL_1B("1b"),
    @XmlEnumValue("2a")
    LEVEL_2A("2a"),
    @XmlEnumValue("2b")
    LEVEL_2B("2b"),
    @XmlEnumValue("2u")
    LEVEL_2U("2u"),
    @XmlEnumValue("3a")
    LEVEL_3A("3a"),
    @XmlEnumValue("3b")
    LEVEL_3B("3b"),
    @XmlEnumValue("3u")
    LEVEL_3U("3u");
    private final String value;

    PdfaLevelType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static PdfaLevelType fromValue(String v) {
        for (PdfaLevelType c: PdfaLevelType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
